==> openshift-serverless-logic-1.26.0-src.zip: openshift-serverless-logic-1.26.0.GA-src/org.kie.kogito-kogito-apps-1.30.0.Final/ui-packages/packages/custom-dashboard-list/src/envelope/CustomDashboardListEnvelopeApiImpl.ts <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { EnvelopeApiFactoryArgs } from '@kogito-tooling/envelope';
import { CustomDashboardListEnvelopeViewApi } from './CustomDashboardListEnvelopeView';
import {
  Association,
  CustomDashboardListChannelApi,
  CustomDashboardListEnvelopeApi
} from '../api';
import { CustomDashboardListEnvelopeContext } from './CustomDashboardListEnvelopeContext';

/**
 * Implementation of the CustomDashboardListEnvelopeApi
 */
export class CustomDashboardListEnvelopeApiImpl
  implements CustomDashboardListEnvelopeApi {
  private capturedInitRequestYet = false;
  constructor(
    private readonly args: EnvelopeApiFactoryArgs<
      CustomDashboardListEnvelopeApi,
      CustomDashboardListChannelApi,
      CustomDashboardListEnvelopeViewApi,
      CustomDashboardListEnvelopeContext
    >
  ) {}

  private hasCapturedInitRequestYet() {
    return this.capturedInitRequestYet;
  }

  private ackCapturedInitRequest() {
    this.capturedInitRequestYet = true;
  }

  customDashboardList__init = async (
    association: Association
  ): Promise<void> => {
    this.args.envelopeBusController.associate(
      association.origin,
      association.envelopeServerId
    );

    if (this.hasCapturedInitRequestYet()) {
      return;
    }

    this.ackCapturedInitRequest();
    this.args.view().initialize();
  };
}

==> openshift-serverless-logic-1.30.0-src.zip: openshift-serverless-logic-1.30.0.GA-src/org.kie.kogito-kogito-apps-1.40.0.Final/ui-packages/packages/custom-dashboard-list/src/envelope/CustomDashboardListEnvelopeApiImpl.ts <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { EnvelopeApiFactoryArgs } from '@kogito-tooling/envelope';
import { CustomDashboardListEnvelopeViewApi } from './CustomDashboardListEnvelopeView';
import {
  Association,
  CustomDashboardListChannelApi,
  CustomDashboardListEnvelopeApi
} from '../api';
import { CustomDashboardListEnvelopeContext } from './CustomDashboardListEnvelopeContext';

/**
 * Implementation of the CustomDashboardListEnvelopeApi
 */
export class CustomDashboardListEnvelopeApiImpl
  implements CustomDashboardListEnvelopeApi
{
  private capturedInitRequestYet = false;
  constructor(
    private readonly args: EnvelopeApiFactoryArgs<
      CustomDashboardListEnvelopeApi,
      CustomDashboardListChannelApi,
      CustomDashboardListEnvelopeViewApi,
      CustomDashboardListEnvelopeContext
    >
  ) {}

  private hasCapturedInitRequestYet() {
    return this.capturedInitRequestYet;
  }

  private ackCapturedInitRequest() {
    this.capturedInitRequestYet = true;
  }

  customDashboardList__init = async (
    association: Association
  ): Promise<void> => {
    this.args.envelopeBusController.associate(
      association.origin,
      association.envelopeServerId
    );

    if (this.hasCapturedInitRequestYet()) {
      return;
    }

    this.ackCapturedInitRequest();
    this.args.view().initialize();
  };
}
